/*
 * Unplayer
 * Copyright (C) 2015-2019 Alexey Rochev <equeim@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.2
import Sailfish.Silica 1.0

import harbour.unplayer 0.1 as Unplayer

Dialog {
    property var tracks

    canAccept: playlistNameField.text.trim()

    onAccepted: {
        if (Array.isArray(tracks)) {
            Unplayer.PlaylistUtils.newPlaylistFromFilesystem(playlistNameField.text.trim(), tracks)
        } else {
            Unplayer.PlaylistUtils.newPlaylistFromLibrary(playlistNameField.text.trim(), tracks)
        }
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: column.height

        Column {
            id: column
            width: parent.width

            DialogHeader {
                title: qsTranslate("unplayer", "Add playlist")
            }

            TextField {
                id: playlistNameField
                label: qsTranslate("unplayer", "Playlist name")
                placeholderText: label
                width: parent.width

                EnterKey.iconSource: "image://theme/icon-m-enter-accept"
                EnterKey.onClicked: accept()

                Component.onCompleted: forceActiveFocus()
            }
        }
    }
}
